import kinterbasdb

# The server is named 'bison'; the database file is at '/temp/test.db'.
con = kinterbasdb.connect(dsn='bison:/temp/test.db', user='sysdba', password='pass')

# Or, equivalently:
con = kinterbasdb.connect(
    host='bison', database='/temp/test.db',
    user='sysdba', password='pass'
  )




#! /usr/bin/env py.test

import sys

if sys.version_info >= (2,5):
    def test_freeze_relimport():
        from bbfreeze import Freezer
        f=Freezer(includes = ['relimport'])
        f()

if __name__=='__main__':
    test_freeze_relimport()
    



from wxPython.wx import *

class MyApp(wxApp):
    def OnInit(self):
        frame = wxFrame(NULL, -1, "Hello from wxPython")
        frame.Show(true)
        self.SetTopWindow(frame)
        return true

app = MyApp(0)
app.MainLoop()

        
